@@ -12,6 +12,8 @@ from media_platform.job.transcode_job import TranscodeSpecification
 from media_platform.lang.serialization import Deserializable, Serializable
 from media_platform.service.callback import Callback
 from media_platform.service.flow_control_service.specifications.add_sources_specification import AddSourcesSpecification
+from media_platform.service.flow_control_service.specifications.change_file_storage_class_specification import \
+    ChangeFileStorageClassSpecification
 from media_platform.service.flow_control_service.specifications.copy_file_specification import CopyFileSpecification
 from media_platform.service.source import Source
 
@@ -25,6 +27,7 @@ class ComponentType:
     playlist = 'av.create_urlset'
     import_file = 'file.import'
     copy_file = 'file.copy'
+    change_file_storage_class = 'file.change_storage_class'
     replace_extra_metadata = 'av.extra_metadata.replace'
     convert_font = 'font.convert'
     add_sources = 'flow.add_sources'
@@ -40,6 +43,7 @@ _SPECIFICATIONS = {
     ComponentType.playlist: None,
     ComponentType.import_file: ImportFileSpecification,
     ComponentType.copy_file: CopyFileSpecification,
+    ComponentType.change_file_storage_class: ChangeFileStorageClassSpecification,
     ComponentType.replace_extra_metadata: ReplaceAudioExtraMetadataSpecification,
     ComponentType.convert_font: ConvertFontSpecification,
     ComponentType.add_sources: AddSourcesSpecification,
