@@ -23,7 +23,7 @@ class _ListRequest(MediaPlatformRequest):
         super().__init__(authenticated_http_client, 'GET', url, payload_type)
         self.next_page_token = None
         self.page_size = 20
-        self.order_by = OrderBy.date_updated
+        self.order_by = None
         self.order_direction = OrderDirection.descending
 
     def set_next_page_token(self, next_page_token: str):
@@ -54,7 +54,7 @@ class _ListRequest(MediaPlatformRequest):
         if self.order_by:
             params['orderBy'] = self.order_by
 
-        if self.order_direction:
-            params['orderDirection'] = self.order_direction
+            if self.order_direction:
+                params['orderDirection'] = self.order_direction
 
         return params
