@@ -1,19 +1,18 @@
+from __future__ import annotations
+
 from media_platform.lang.serialization import Serializable, Deserializable
 
 
 class GeoLocation(Serializable, Deserializable):
-    def __init__(self, latitude=None, longitude=None, ip_address=None, country=None, city=None):
-        # type: (float, float, str, str, str) -> None
-
+    def __init__(self, latitude: float = None, longitude: float = None, ip_address: str = None, country: str = None,
+                 city: str = None):
         self.latitude = latitude
         self.longitude = longitude
         self.ip_address = ip_address
         self.country = country
         self.city = city
 
-    def serialize(self):
-        # type: () -> dict
-
+    def serialize(self) -> dict:
         return {
             'coordinates': {
                 'latitude': self.latitude,
@@ -25,9 +24,7 @@ class GeoLocation(Serializable, Deserializable):
         }
 
     @classmethod
-    def deserialize(cls, data):
-        # type: (dict) -> GeoLocation
-
+    def deserialize(cls, data: dict) -> GeoLocation:
         coordinates_data = data.get('coordinates') or {}
         return cls(coordinates_data.get('latitude'),
                    coordinates_data.get('longitude'),
